pub enum GcError {
Internal,
PendingCommit,
// some variants omitted
}Expand description
The error type for [Manager.Gc].
Variants
Internal
PendingCommit
The system is in the process of being updated, and the current system version has not yet
been committed. Garbage collection is blocked to protect the blobs required by the previous
system version. Consumers may use
[fuchsia.update/CommitStatusProvider.IsCurrentSystemCommitted] to be notified if and when
the current system is committed.
Implementations