pub enum ManagerRequest {
Gc {
responder: ManagerGcResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: ManagerControlHandle,
method_type: MethodType,
},
}Expand description
An abstract representation of the packaging system’s garbage collector.
Variants
Gc
Trigger garbage collection. The package management system will make a best-effort attempt to free up storage space by deleting unnecessary blobs.
Fields

responder: ManagerGcResponder#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: ManagerControlHandle
method_type: MethodTypeImplementations
Sourceimpl ManagerRequest
impl ManagerRequest
pub fn into_gc(self) -> Option<ManagerGcResponder>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL